const join = (value, separator) => value.join(separator);
const split = (value, separator) => (value === null || value === void 0 ? void 0 : value.split(separator).filter((str) => str.trim() !== '')) || [];
const intSerializer = {
    deserialize: (value) => {
        if (value === null) {
            return value;
        }
        const num = parseInt(value, 10);
        return Number.isNaN(num) ? null : num;
    },
    serialize: (value) => String(value),
};
const floatSerializer = {
    deserialize: (value) => {
        if (value === null) {
            return value;
        }
        const num = parseFloat(value);
        return Number.isNaN(num) ? null : num;
    },
    serialize: (value) => String(value),
};
const stringSerializer = {
    deserialize: (value) => value === null ? null : String(value),
    serialize: (value) => String(value),
};
export const arrayStringSerializer = (separator) => ({
    deserialize: (value) => split(value, separator),
    serialize: (value) => value ? join(value, separator) : null,
});
export const arrayIntSerializer = (separator) => ({
    deserialize: (value) => split(value, separator).map(intSerializer.deserialize),
    serialize: (value) => value ? join(value, separator) : null,
});
export const arrayFloatSerializer = (separator) => ({
    deserialize: (value) => split(value, separator).map(floatSerializer.deserialize),
    serialize: (value) => value ? join(value, separator) : null,
});
const dateSerializer = (locale = 'en-us', timeZone = 'UTC') => ({
    deserialize: (value) => value ? new Date(value) : new Date(),
    serialize: (value) => value === null || value === void 0 ? void 0 : value.toLocaleDateString(locale, { timeZone }),
});
const booleanSerializer = {
    deserialize: (value) => value === '1',
    serialize: (value) => (value ? '1' : '0'),
};
export const DEFAULT_SEPARATOR = '_';
export const serializers = {
    arrayFloat: arrayFloatSerializer(DEFAULT_SEPARATOR),
    arrayInt: arrayIntSerializer(DEFAULT_SEPARATOR),
    arrayString: arrayStringSerializer(DEFAULT_SEPARATOR),
    boolean: booleanSerializer,
    date: dateSerializer,
    float: floatSerializer,
    int: intSerializer,
    string: stringSerializer,
};
